@@ -16,14 +16,14 @@ class Project(Enum):
 class ProjectInfo:
     def __init__(
         self,
-        project: Project,
+        project: str,
         client_key_name: str,
         base_url: str = None,
     ):
-        self.name: str = project.value
+        self.name: str = project
         self.client_key_name: str = client_key_name
         self.base_url: Optional[str] = base_url
-        self.project: Project = project
+        self.project: str = project
 
     def get_client_api_key(self) -> str:
         return env.get_env_value(self.client_key_name)
